# Generated by Django 3.2 on 2021-08-25 04:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("simpl", "0012_remove_lobby_ready"),
    ]

    operations = [
        migrations.AddField(
            model_name="gameexperience",
            name="multiplayer",
            field=models.BooleanField(
                blank=True,
                help_text="Whether multiple players play a single instance of the game. If unset, this become configurable at the run level.",
                null=True,
            ),
        ),
    ]
