# Generated by Django 2.2.22 on 2021-07-12 02:40

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("simpl", "0005_auto_20210712_0038"),
    ]

    operations = [
        migrations.AlterField(
            model_name="instance",
            name="run",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.SIMPL_RUN,
            ),
        ),
        migrations.AlterField(
            model_name="lobby",
            name="run",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE, to=settings.SIMPL_RUN
            ),
        ),
        migrations.AlterField(
            model_name="player",
            name="run",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE, to=settings.SIMPL_RUN
            ),
        ),
    ]
