# Generated by Django 3.2.4 on 2021-06-16 02:54

from django.db import migrations, models

try:
    from django.db.models import JSONField
except ImportError:
    from django.contrib.postgres.fields import JSONField


class Migration(migrations.Migration):

    dependencies = [
        ("simpl", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="run",
            name="data",
            field=JSONField(blank=True, default=dict, editable=False),
        ),
    ]
