<ol class="game-stage-list">
  <li class="game-stage-item">
    <span class="
        game-stage-link {% if run.status == run.STATUS.SETUP %}is-this-step{% endif %}

        {% if run.status > run.STATUS.SETUP %}is-complete{% endif %}
        ">
      <span>Setup</span>
    </span>
  </li>
  {% if run.use_status_prepare %}
  <li class="game-stage-item">
    <span class="
        game-stage-link {% if run.status == run.STATUS.PREPARE %}is-this-step{% endif %}
        {% if run.status > run.STATUS.PREPARE %}is-complete{% endif %}
        ">
      <span>Players Prepare</span>
    </span>
  </li>
  {% endif %}
  <li class="game-stage-item">
    <span class="
        game-stage-link {% if run.status == run.STATUS.PLAY and not run.ended %}is-this-step{% endif %}
        {% if run.status > run.STATUS.PLAY or run.ended %}is-complete{% endif %}
        ">
      <span>Play</span>
    </span>
  </li>
  {% if run.use_status_debrief %}
  <li class="game-stage-item">
    <span class="
        game-stage-link {% if run.status == run.STATUS.DEBRIEF and not run.ended %}is-this-step{% endif %}
        {% if run.status > run.STATUS.DEBRIEF %}is-complete{% endif %}
        ">
      <span>Player Reports</span>
    </span>
  </li>
  {% endif %}
  {% if run.can_end %}
  <li class="game-stage-item">
    <span class="
        game-stage-link {% if run.status == run.STATUS.COMPLETE or run.ended %}is-this-step{% endif %}
        {% if run.status > run.STATUS.COMPLETE %}is-complete{% endif %}
        ">
      <span>End Game</span>
    </span>
  </li>
  {% endif %}
</ol>
