{% extends "simpl/base.html" %}

{% block arrows %}
{% include 'simpl/includes/status-arrows.html' %}
{% endblock arrows %}

{% block heading %}
{% if not run.ended %}
The Game is in Play
{% else %}
The Game is Finished
{% endif %}
{% endblock %}

{% block content_inner %}
{{ block.super }}
{% include 'simpl/includes/form_end.html' %}
{% endblock %}