{% load simpl %}
<div class="player-item no-checkbox">
  <div class="avatar-detail">
    <div class="avatar" style="background:{{ player|playercolor }}">
      <div class="avatar-inner">
        {{ player|playerinitials }}
      </div>
    </div>

    <p class="avatar-detail-meta">{{ player.public_name }}</p>
  </div>
  {{ contents }}
</div>
