# Generated by Django 3.2 on 2021-08-24 18:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('simpl', '0011_gameexperience_experience_id'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='lobby',
            name='ready',
        ),
    ]
