{% extends "simpl/base.html" %}
{% load includecontents %}

{% block main_wrap_classes %}v-nav-flex-layout{% endblock %}

{% block arrows %}
{% include 'simpl/includes/status-arrows.html' %}
{% endblock arrows %}

{% block heading %}
{% if run.status == run.STATUS.PREPARE %}
Players Preparing
{% else %}
Players Prepare
{% endif %}
{% endblock %}

{% block content_inner %}
{{ block.super }}
{% include 'simpl/includes/form_prepare.html' %}
{% endblock %}
