# Generated by Django 3.2 on 2021-09-16 17:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('simpl', '0017_run_date_continuous_end'),
    ]

    operations = [
        migrations.AddField(
            model_name='apitoken',
            name='name',
            field=models.CharField(blank=True, max_length=100),
        ),
    ]
