{% if run.status < run.STATUS.PLAY %}
    <p class="walkthrough-help-heading">
      The Game is currently in Setup.
    </p>
    <p class="walkthrough-help-text">
      These players are enrolled in the game and ready to play. You may now enable Players Prepare and Start Game in <strong>Game Status</strong>.
    </p>
{% endif %}

{% if run.status == run.STATUS.PLAY and not run.ended %}
  <p class="walkthrough-help-heading">
    The Game is currently in Play.
  </p>
{% elif run.ended %}
<p class="walkthrough-help-heading">
  Gameplay has ended.
</p>
{% endif %}

{% if inactive_players %}
  <p class="walkthrough-help-heading">
    <strong>There {{ inactive_players|pluralize:"is,are" }}
    {{ inactive_players|length }}{% if inactive_players|length != inactive_count %}/{{ inactive_count }}{% endif %}
    Inactive player{{ inactive_players|pluralize }}</strong>.
  </p>

  {% if run.status < run.STATUS.PLAY or run.continuous %}
  <p class="walkthrough-help-text">
    Select "Mark Active" next to {{ inactive_players|pluralize:"this,each" }}
    player's name to allow them to join. They will
    be notified and added immediately to a new game.
  </p>
  {% endif %}
{% endif %}
