{% extends "simpl/base.html" %}

{% block arrows %}
{% include 'simpl/includes/status-arrows.html' %}
{% endblock arrows %}

{% block heading %}Start {% if not run.multiplayer %}Practice{% endif %} Game{% endblock %}

{% block content_inner %}
{{ block.super }}
{% include 'simpl/includes/form_start.html' %}
{% endblock %}
