{% extends "simpl/base.html" %}

{% block main_wrap_classes %}v-nav-flex-layout{% endblock %}

{% block heading %}Configure Gameplay{% endblock %}

{% block content_inner %}
{{ block.super }}
{% endblock %}
