{% load static %}
{% load includecontents %}
<!DOCTYPE html>
<html class="nav-is-closed" lang="en">

<head>
  <meta charset="utf-8" />
  <title>ARC Game Management | {{ run.game.name }}</title>
  <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
  <link rel="stylesheet" href="{% static 'simpl/style.css' %}" />
  {% block extra_head %}{% endblock %}
</head>

<body class="{% if run.multiplayer %}theme-alt{% endif %}">
  {% block header %}{% include "simpl/includes/site-header.html" %}{% endblock header %}

  <main class="{% block main_wrap_classes %}v-nav-flex-layout{% endblock %}">
    {% block content %}

    {% block game_stage_steps %}
    {% endblock game_stage_steps %}

    {% block page_header %}
    <header class="page-header">
      {% block arrows %}{% endblock arrows %}
      <h1 class="page-heading">{% block heading %}{% endblock %}</h1>
      <p class="page-header-description">{% block page_description %}{% endblock %}</p>

      {% block messages %}
        {% include "simpl/includes/messages.html" %}
      {% endblock messages %}
    </header>
    {% endblock page_header %}

    <div class="edu-has-v-nav">
      {% block left_nav %}
      <nav class="v-nav">
        <ul class="v-nav-list">
          {% for nav_key, item in simpl_nav.items %}
          {% if not item.hidden %}
          <li class="v-nav-item">
            <a {% if item.status != NAV_DISABLED %}href="{{ item.url }}" {% endif %}class="v-nav-link"
              {% if nav_key == simpl_current_nav %}aria-current="page" {% endif %}>
              {% include "simpl/includes/nav-icon.html" %}
              <span class="v-nav-text">{{ item.name }}</span>
            </a>
          </li>
          {% endif %}
          {% endfor %}
        </ul>
      </nav>
      {% endblock %}

      {% block content_inner %}

      {% endblock content_inner %}
    </div>

    {% endblock content %}
    <p
      class="copyright-text">
      ©{% now "Y" %}, The Wharton School, The University of Pennsylvania</p>
  </main>

  <script type="module">
  import { initComponents } from "{% static 'simpl/simpl.es.js' %}";
  initComponents();
  </script>
  {% block extra_script %}{% endblock %}
</body>

</html>
