# Generated by Django 2.2.22 on 2021-07-20 05:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("simpl", "0006_auto_20210712_0240"),
    ]

    operations = [
        migrations.AlterField(
            model_name="lobby",
            name="name",
            field=models.CharField(max_length=100),
        ),
    ]
