# Generated by Django 2.2.22 on 2021-07-12 00:38

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("simpl", "0004_rename_token_apitoken"),
    ]

    operations = [
        migrations.AlterField(
            model_name="run",
            name="managers",
            field=models.ManyToManyField(
                blank=True,
                related_name="simpl_run_set",
                related_query_name="simpl_run",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]
